"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const FTPConfig_1 = require("./api/FTPConfig");
/**
 * This class is used by the various zos-ftp handlers as the base class for their implementation.
 * All handlers within zos-ftp should extend this class.
 *
 */
class FTPBaseHandler {
    /**
     * This will grab the zos-ftp profile and create a connection before calling the subclass
     *
     * @param commandParameters Command parameters sent by imperative.
     *
     */
    process(commandParameters) {
        return __awaiter(this, void 0, void 0, function* () {
            let connection;
            try {
                connection = yield FTPConfig_1.FTPConfig.connectFromArguments(commandParameters.arguments);
                this.log.info("Connected to FTP successfully");
                const additionalParameters = commandParameters;
                additionalParameters.connection = connection;
                yield this.processFTP(additionalParameters);
            }
            catch (e) {
                this.log.error("Error encountered in FTP command:\n%s", require("util").inspect(e));
                throw new imperative_1.ImperativeError({ msg: e.message, causeErrors: [e] });
            }
            finally {
                // close the connection whether we saw an error or not
                if (connection != null) {
                    this.log.debug("Closing FTP connection");
                    connection.close();
                }
            }
        });
    }
    get log() {
        return imperative_1.Logger.getAppLogger();
    }
}
exports.FTPBaseHandler = FTPBaseHandler;
//# sourceMappingURL=FTPBase.Handler.js.map