"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const util_1 = require("util");
class CoreUtils {
    /**
     * Sleep for a number of milliseconds
     * @param ms - how many miliseconds to sleep or (at least)
     * @returns promise that resolves when the sleep is complete (or after, not guaranteed)
     */
    static sleep(ms) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Sleeping for %s milliseconds...", ms);
            return new Promise((resolve) => setTimeout(resolve, ms));
        });
    }
    /**
     * Make sure newlines in a string have carriage returns
     * This is required to prevent errors when transferring
     * in ascii mode
     * @param  original - the original string which you would like to ensure has \r before \n
     * @returns a string where every \n has a \r before it
     */
    static addCarriageReturns(original) {
        this.log.debug("Adding carriage returns to string of length %s", original.length);
        return original.replace(/\r?\n/g, "\r\n");
    }
    /**
     * Read the complete contents of stdin
     * @returns contents piped in to stdin
     */
    static readStdin() {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                let stdinContent = Buffer.from([]);
                const stream = process.stdin;
                stream.resume();
                stream.on("data", (chunk) => {
                    this.log.trace(`Read data from stdin: ${chunk.toString()}`);
                    this.log.debug(`Read ${chunk.length} bytes of data from stdin`);
                    stdinContent = Buffer.concat([stdinContent, chunk]);
                });
                stream.once("end", () => {
                    this.log.info("Finished reading stdin");
                    resolve(stdinContent);
                });
                stream.on("error", (error) => {
                    const stdinReadError = {
                        msg: "Error encountered while reading from stdin",
                        causeErrors: error,
                        additionalDetails: (util_1.isNullOrUndefined(error)) ? undefined : error.message
                    };
                    reject(stdinReadError);
                });
            });
        });
    }
    static get log() {
        return imperative_1.Logger.getAppLogger();
    }
}
exports.CoreUtils = CoreUtils;
//# sourceMappingURL=CoreUtils.js.map