"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../");
const ibmdb = require("ibm_db");
/**
 * Class to handle execution of SQL statements
 * @export
 * @class ExecuteSQL
 */
class ExecuteSQL {
    /**
     * Constructor
     * @param {IDB2Session} session DB2 session parameters
     */
    constructor(session) {
        __1.SessionValidator.validate(session);
        this.mConnectionString = __1.ConnectionString.buildFromSession(session);
    }
    /**
     * Execute a SQL statement
     * @param {string} sql Statement to execute
     * @param {IDB2Parameter[]} parameters Array of DB2 parameters to bind to the SQL statement
     * @returns {IterableIterator<any>}
     * @static
     * @memberof ExecuteSQL
     */
    *execute(sql, parameters) {
        const options = {
            fetchMode: __1.DB2Constants.FETCH_MODE_OBJECT,
        };
        let result;
        try {
            this.mConnection = ibmdb.openSync(this.mConnectionString, options);
            result = this.mConnection.queryResultSync(sql, parameters);
            if (result instanceof Error) {
                throw result;
            }
            yield result.fetchAllSync();
            while (result.moreResultsSync()) {
                yield result.fetchAllSync();
            }
            this.mConnection.closeSync();
        }
        catch (err) {
            __1.DB2Error.process(err);
        }
    }
}
exports.ExecuteSQL = ExecuteSQL;
//# sourceMappingURL=ExecuteSQL.js.map