"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const MQ_messages_1 = require("./rest/constants/MQ.messages");
const MQ_constants_1 = require("./rest/constants/MQ.constants");
const MQRestClient_1 = require("./rest/MQRestClient");
const path_1 = require("path");
/**
 * Class of utility file APIs for usage within the CLI and programmatically from node scripts.
 * @export
 * @class Command
 */
class MQSCCommand {
    /**
     * Runs the specified MQSC command on the specified queue manager.
     * @param {MQSession}  session      - MQ connection info
     * @param {string} queueMgrName - The Queue manager to apply command to
     * @param {string} command - The command to be run.
     * @param {boolean} csrfHeader - Set the CSRF protection header, default is true
     * @throws ImperativeError
     * @memberof Command
     */
    static async qmgrAction(session, queueMgrName, thecommand, csrfHeader = true) {
        imperative_1.ImperativeExpect.toNotBeNullOrUndefined(queueMgrName, MQ_messages_1.MQMessages.missingQueueManagerName.message);
        imperative_1.ImperativeExpect.toNotBeEqual(queueMgrName, "", MQ_messages_1.MQMessages.missingQueueManagerName.message);
        imperative_1.ImperativeExpect.toNotBeNullOrUndefined(thecommand, MQ_messages_1.MQMessages.missingCommand.message);
        imperative_1.ImperativeExpect.toNotBeEqual(thecommand, "", MQ_messages_1.MQMessages.missingCommand.message);
        const endpoint = path_1.posix.join(MQ_constants_1.MQConstants.RESOURCE, MQ_constants_1.MQConstants.RES_QUEUE_MANAGER_COMMAND, queueMgrName, MQ_constants_1.MQConstants.RES_QUEUE_MANAGER_ACTION);
        const payload = { type: "runCommand", parameters: { command: thecommand } };
        const headers = (csrfHeader === true)
            ? [{ "Content-Type": "application/json" }, { "ibm-mq-rest-csrf-token": "true" }]
            : [{ "Content-Type": "application/json" }];
        const content = await MQRestClient_1.MQRestClient.postExpectJSON(session, endpoint, headers, payload);
        return content;
    }
}
exports.default = MQSCCommand;
//# sourceMappingURL=MQSCCommand.js.map