"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
class StreamUtils {
    /**
     * @param  estimatedSize - estimated file size
     * @param  stremPromise - promise that will resolve to a readable stream
     * @param  response - response object from your handler, provide if
     *                                         you want a progress bar created
     * @returns  - promise that resolves when the h
     */
    static streamToBuffer(estimatedSize, streamPromise, response) {
        return __awaiter(this, void 0, void 0, function* () {
            const PERCETAGE = 100;
            return new Promise((resolve, reject) => {
                let data = Buffer.from([]);
                const statusMessage = "Downloaded %d of %d (Estimated) bytes";
                const task = {
                    statusMessage: "Starting transfer...",
                    percentComplete: 0,
                    stageName: imperative_1.TaskStage.IN_PROGRESS
                };
                if (response != null) {
                    response.progress.startBar({ task });
                }
                streamPromise.then((stream) => {
                    stream.on("data", (chunk) => {
                        data = Buffer.concat([data, chunk]);
                        task.percentComplete = PERCETAGE * data.length / estimatedSize;
                        task.statusMessage = imperative_1.TextUtils.formatMessage(statusMessage, data.length, estimatedSize);
                    });
                    stream.on("end", () => {
                        if (response != null) {
                            response.progress.endBar();
                        }
                        resolve(data);
                    });
                    stream.on("error", (error) => {
                        if (response != null) {
                            response.progress.endBar();
                        }
                        reject(error);
                    });
                    stream.resume();
                }).catch((streamRejection) => {
                    reject(streamRejection);
                });
            });
        });
    }
    /**
     * Pipes the readable stream to the writable stream.
     *
     * @param  estimatedSize - estimated file size
     * @param  stremPromise - promise that will resolve to a readable stream
     * @param  writable - writable stream
     * @param  response - response object from your handler, provide if
     *                                         you want a progress bar created
     * @returns  - promise that resolves when the h
     */
    static streamToStream(estimatedSize, streamPromise, writable, response) {
        return __awaiter(this, void 0, void 0, function* () {
            const PERCETAGE = 100;
            return new Promise((resolve, reject) => {
                let downloadedBytes = 0;
                const statusMessage = "Downloaded %d of %d bytes";
                const task = {
                    statusMessage: "Starting transfer...",
                    percentComplete: 0,
                    stageName: imperative_1.TaskStage.IN_PROGRESS
                };
                if (response != null) {
                    response.progress.startBar({ task });
                }
                streamPromise.then((stream) => {
                    stream.pipe(writable);
                    stream.on("data", (chunk) => {
                        downloadedBytes += chunk.length;
                        task.percentComplete = PERCETAGE * downloadedBytes / estimatedSize;
                        task.statusMessage = imperative_1.TextUtils.formatMessage(statusMessage, downloadedBytes, estimatedSize);
                    });
                    stream.on("end", () => {
                        if (response != null) {
                            response.progress.endBar();
                        }
                        resolve("end");
                    });
                    stream.on("error", (error) => {
                        if (response != null) {
                            response.progress.endBar();
                        }
                        reject(error);
                    });
                }).catch((streamRejection) => {
                    reject(streamRejection);
                });
            });
        });
    }
}
exports.StreamUtils = StreamUtils;
//# sourceMappingURL=StreamUtils.js.map