"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const rest_1 = require("../../rest");
const constants_1 = require("../../constants");
/**
 * Refresh a program definition on CICS through CMCI REST API
 * @param {AbstractSession} session - the session to connect to CMCI with
 * @param {IProgramParms} parms - parameters for refreshing your program
 * @returns {Promise<any>} promise that resolves to the response (XML parsed into a javascript object)
 *                          when the request is complete
 * @throws {ImperativeError} CICS program name not defined or blank
 * @throws {ImperativeError} CICS region name not defined or blank
 * @throws {ImperativeError} CicsCmciRestClient request fails
 */
function programNewcopy(session, parms) {
    return __awaiter(this, void 0, void 0, function* () {
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.name, "CICS Program name", "CICS program name is required");
        imperative_1.ImperativeExpect.toBeDefinedAndNonBlank(parms.regionName, "CICS Region name", "CICS region name is required");
        imperative_1.Logger.getAppLogger().debug("Attempting to refresh a program with the following parameters:\n%s", JSON.stringify(parms));
        const requestBody = {
            request: {
                action: {
                    $: {
                        name: "NEWCOPY",
                    }
                }
            }
        };
        const cicsPlex = parms.cicsPlex == null ? "" : parms.cicsPlex + "/";
        const cmciResource = "/" + constants_1.CicsCmciConstants.CICS_SYSTEM_MANAGEMENT + "/" +
            constants_1.CicsCmciConstants.CICS_PROGRAM_RESOURCE + "/" + cicsPlex + parms.regionName +
            "?CRITERIA=(PROGRAM=" + parms.name + ")";
        return rest_1.CicsCmciRestClient.putExpectParsedXml(session, cmciResource, [], requestBody);
    });
}
exports.programNewcopy = programNewcopy;
//# sourceMappingURL=Set.js.map