"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const UssUtils_1 = require("../../../api/UssUtils");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
class DeleteUSSFileHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const ussFile = UssUtils_1.UssUtils.normalizeUnixPath(params.arguments.ussFile);
            this.log.debug("Deleting USS file '%s'", ussFile);
            if (params.arguments.recursive) {
                yield this.deleteDirectory(params, ussFile);
            }
            else {
                yield params.connection.deleteDataset(ussFile);
            }
            const successMsg = params.response.console.log("Successfully deleted USS file %s", ussFile);
            params.response.data.setMessage(successMsg);
            this.log.info(successMsg);
        });
    }
    deleteDirectory(params, ussFile) {
        return __awaiter(this, void 0, void 0, function* () {
            const files = yield params.connection.listDataset(ussFile);
            for (const file of files) {
                const filePath = path.join(ussFile, file.name);
                if (file.isDirectory) {
                    yield this.deleteDirectory(params, filePath);
                }
                else {
                    yield params.connection.deleteDataset(filePath);
                    params.response.console.log("Deleted %s", filePath);
                }
            }
            yield params.connection.deleteDataset(ussFile);
            params.response.console.log("Deleted %s", ussFile);
        });
    }
}
exports.default = DeleteUSSFileHandler;
//# sourceMappingURL=UssFile.Handler.js.map