"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const imperative_1 = require("@zowe/imperative");
const StreamUtils_1 = require("../../../api/StreamUtils");
const cli_1 = require("@zowe/cli");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
class DownloadDataSetHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const transferType = params.arguments.binary ? "binary" : "ascii";
            const file = params.arguments.file == null ?
                cli_1.ZosFilesUtils.getDirsFromDataSet(params.arguments.dataSet) :
                params.arguments.file;
            const files = yield params.connection.listDataset(params.arguments.dataSet);
            if (files === undefined || files.length === 0) {
                throw new Error(`The dataset "${params.arguments.dataSet}" doesn't exist.`);
            }
            this.log.debug("Downloading data set '%s' to local file '%s' in transfer mode '%s", params.arguments.dataSet, file, transferType);
            imperative_1.IO.createDirsSyncFromFilePath(file);
            const contentStreamPromise = params.connection.getDataset(params.arguments.dataSet, transferType, true);
            const TRACK = 56664;
            const estimatedSize = parseInt(files[0].Used, 10) * TRACK;
            const writable = fs.createWriteStream(file);
            yield StreamUtils_1.StreamUtils.streamToStream(estimatedSize, contentStreamPromise, writable, params.response);
            const successMsg = params.response.console.log(cli_1.ZosFilesMessages.datasetDownloadedSuccessfully.message, file);
            this.log.info(successMsg);
            params.response.data.setMessage(successMsg);
        });
    }
}
exports.default = DownloadDataSetHandler;
//# sourceMappingURL=DataSet.Handler.js.map