"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const imperative_1 = require("@zowe/imperative");
const StreamUtils_1 = require("../../../api/StreamUtils");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
const UssUtils_1 = require("../../../api/UssUtils");
const path_1 = require("path");
class DownloadUssFileHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const ussFile = UssUtils_1.UssUtils.normalizeUnixPath(params.arguments.ussFile);
            const transferType = params.arguments.binary ? "binary" : "ascii";
            const file = params.arguments.file == null ?
                path_1.basename(ussFile) : // default the destination file name to the basename of the uss file e.g. /u/users/ibmuser/hello.txt -> hello.txt
                params.arguments.file;
            const files = yield params.connection.listDataset(path_1.dirname(ussFile));
            const fileToDownload = files.find((f) => {
                return f.name === path_1.basename(ussFile);
            });
            if (fileToDownload === undefined) {
                throw new Error(`The file "${ussFile}" doesn't exist.`);
            }
            this.log.debug("Downloading USS file '%s' to local file '%s' in transfer mode '%s", ussFile, file, transferType);
            imperative_1.IO.createDirsSyncFromFilePath(file);
            const contentStreamPromise = params.connection.getDataset(ussFile, transferType, true);
            const writable = fs.createWriteStream(file);
            yield StreamUtils_1.StreamUtils.streamToStream(fileToDownload.size, contentStreamPromise, writable, params.response);
            const successMsg = params.response.console.log("Successfully downloaded USS file '%s' to local file '%s'", ussFile, file);
            this.log.info(successMsg);
            params.response.data.setMessage(successMsg);
        });
    }
}
exports.default = DownloadUssFileHandler;
//# sourceMappingURL=UssFile.Handler.js.map