"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
class ListDataSetMembersHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            let members;
            this.log.debug("Listing members of dataset %s", params.arguments.dsname);
            const datasetname = params.arguments.dsname + "(*)";
            members = yield params.connection.listDataset(datasetname);
            this.log.debug("Found %d members", members.length);
            const filteredMembers = members.map((file) => {
                const result = {};
                for (const key of Object.keys(file)) {
                    // turn the object into a similar format to that returned by
                    // z/osmf so that users who use the list ds command in main
                    // zowe can use the same filtering options
                    this.log.trace("Remapping key for data set to match core CLI. Old key '%s' New key '%s'", key, key.toLowerCase());
                    result[key.toLowerCase()] = file[key];
                }
                return result;
            });
            params.response.data.setObj(filteredMembers);
            const successMsg = params.response.console.log("Successfully listed %d members in data sets %s", filteredMembers.length, params.arguments.dsname);
            this.log.info(successMsg);
            params.response.data.setMessage("Successfully listed %d members in data sets %s", filteredMembers.length, params.arguments.dsname);
            params.response.format.output({
                output: filteredMembers,
                format: "table",
                fields: ["name"]
            });
        });
    }
}
exports.default = ListDataSetMembersHandler;
//# sourceMappingURL=DataSetMembers.Handler.js.map