"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const JobUtils_1 = require("../../../api/JobUtils");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
class ListJobsHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            let jobs;
            const option = {
                jobName: params.arguments.prefix,
            };
            let debugMessage = `Listing jobs that match prefix ${params.arguments.prefix}`;
            if (params.arguments.owner) {
                option.owner = params.arguments.owner;
                debugMessage += ` and are owned by ${option.owner}`;
            }
            this.log.debug(debugMessage);
            jobs = yield params.connection.listJobs(option);
            this.log.debug("List returned %d jobs", jobs.length);
            const filteredJobs = JobUtils_1.JobUtils.parseJobDetails(jobs);
            params.response.data.setObj(filteredJobs);
            params.response.data.setMessage("Successfully listed %d matching jobs", jobs.length);
            params.response.format.output({
                output: filteredJobs,
                format: "table",
                fields: ["jobid", "jobname", "owner", "status"]
            });
        });
    }
}
exports.default = ListJobsHandler;
//# sourceMappingURL=Jobs.Handler.js.map