"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
const JobUtils_1 = require("../../../api/JobUtils");
/**
 * "zos-ftp list spool-files" command handler. Outputs a table of spool files.
 */
class ListSpoolFilesByJobidHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Listing spool files for job ID %s", params.arguments.jobid);
            const job = yield JobUtils_1.JobUtils.findJobByID(params.arguments.jobid, params.connection);
            const files = job.spoolFiles;
            const successMessage = this.log.info(`"${files.length}" spool files obtained for job "${job.jobname}(${job.jobid})"`);
            // Set the object, message, and log the prettified object
            params.response.data.setObj(files);
            params.response.data.setMessage(successMessage);
            // Format & print the response
            params.response.format.output({
                fields: ["id", "ddname", "procstep", "stepname"],
                output: files,
                format: "table"
            });
        });
    }
}
exports.default = ListSpoolFilesByJobidHandler;
//# sourceMappingURL=SpoolFilesByJobid.Handler.js.map