"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const api_1 = require("../../../api");
const ImsBaseHandler_1 = require("../../ImsBaseHandler");
// Does not use the import in anticipation of some internationalization work to be done later.
const strings = require("../../-strings-/en").default.START.RESOURCES.PROGRAM;
/**
 * Command handler for starting IMS programs
 * @export
 * @class ProgramHandler
 * @implements {ICommandHandler}
 */
class ProgramHandler extends ImsBaseHandler_1.ImsBaseHandler {
    processWithSession(params, session, profile) {
        return __awaiter(this, void 0, void 0, function* () {
            const status = {
                statusMessage: "Start program defined to IMS",
                percentComplete: 0,
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            params.response.progress.startBar({ task: status });
            const response = yield api_1.startProgram(session, {
                name: params.arguments.name,
                start: params.arguments.attributes,
                route: params.arguments.route
            });
            this.checkReturnCode(response);
            params.response.console.log(imperative_1.TextUtils.prettyJson(response.data));
            imperative_1.Logger.getAppLogger().info("Messages from the start program API:\n" + JSON.stringify(response.messages, null, 2));
            return response;
        });
    }
}
exports.default = ProgramHandler;
//# sourceMappingURL=Program.handler.js.map