"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const UssUtils_1 = require("../../../api/UssUtils");
const CoreUtils_1 = require("../../../api/CoreUtils");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
class UploadFileToUssFileHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const transferType = params.arguments.binary ? "binary" : "ascii";
            let content = imperative_1.IO.readFileSync(params.arguments.file, undefined, params.arguments.binary);
            const uploadSource = "local file '" + params.arguments.file + "'";
            if (!params.arguments.binary) {
                // if we're not in binary mode, we need carriage returns to avoid errors
                content = Buffer.from(CoreUtils_1.CoreUtils.addCarriageReturns(content.toString()));
            }
            const ussFile = UssUtils_1.UssUtils.normalizeUnixPath(params.arguments.ussFile);
            this.log.debug("Attempting to upload from local file '%s' to USS file '%s' in transfer mode '%s'", params.arguments.file, ussFile, transferType);
            yield params.connection.uploadDataset(content, ussFile, transferType);
            const successMsg = params.response.console.log("Uploaded from %s to %s ", uploadSource, ussFile);
            params.response.data.setMessage(successMsg);
            this.log.info(successMsg);
        });
    }
}
exports.default = UploadFileToUssFileHandler;
//# sourceMappingURL=FileToUssFile.Handler.js.map