"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const JobUtils_1 = require("../../../api/JobUtils");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
const imperative_1 = require("@zowe/imperative");
class ViewAllSpoolByJobIdHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Viewing all spool files for job id: " + params.arguments.jobid);
            const spoolFiles = [];
            const fullSpoolFiles = [];
            const jobDetails = (yield JobUtils_1.JobUtils.findJobByID(params.arguments.jobid, params.connection));
            if (jobDetails.spoolFiles == null || jobDetails.spoolFiles.length === 0) {
                throw new imperative_1.ImperativeError({
                    msg: imperative_1.TextUtils.formatMessage("No spool files were available for job %s(%s). " +
                        "Try again after waiting a moment if the job is not yet in OUTPUT status.", jobDetails.jobname, jobDetails.jobid)
                });
            }
            for (const spoolFileToDownload of jobDetails.spoolFiles) {
                this.log.debug("Requesting spool files for job %s(%s) spool file ID %d", jobDetails.jobname, jobDetails.jobid, spoolFileToDownload.id);
                const option = {
                    jobName: jobDetails.jobname,
                    jobId: jobDetails.jobid,
                    owner: "*",
                    fileId: spoolFileToDownload.id
                };
                const spoolFile = yield params.connection.getJobLog(option);
                spoolFiles.push(spoolFile);
                spoolFileToDownload.contents = spoolFile;
                fullSpoolFiles.push(spoolFileToDownload);
            }
            params.response.data.setObj(fullSpoolFiles);
            params.response.console.log(spoolFiles.join("\n"));
        });
    }
}
exports.default = ViewAllSpoolByJobIdHandler;
//# sourceMappingURL=AllSpoolByJobId.Handler.js.map