"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const StreamUtils_1 = require("../../../api/StreamUtils");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
const TRACK = 56664;
class ViewDataSetHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const transferMode = params.arguments.binary ? "binary" : "ascii";
            const files = yield params.connection.listDataset(params.arguments.dataSet);
            if (files === undefined || files.length === 0) {
                throw new Error(`The dataset "${params.arguments.dataSet}" doesn't exist.`);
            }
            let content;
            this.log.debug("Attempting to view data set '%s' in transfer mode '%s'", params.arguments.dataSet, transferMode);
            const contentStreamPromise = params.connection.getDataset(params.arguments.dataSet, transferMode, true);
            const size = parseInt(files[0].Used, 10) * TRACK;
            content = yield StreamUtils_1.StreamUtils.streamToBuffer(size, contentStreamPromise, params.response);
            this.log.info("Successfully downloaded %d bytes of content from %s", content.length, params.arguments.dataSet);
            params.response.data.setObj(content);
            params.response.console.log(content);
        });
    }
}
exports.default = ViewDataSetHandler;
//# sourceMappingURL=DataSet.Handler.js.map